# StenoBee
>

>
Plover plugin for Spelling Based Stenography
>
Created by Tink & Emily & Kaoffie
>
With lots of help from, Jen and paulfioravanti :)
>

>
![1](https://github.com/Tink-Bell/StenoBee/assets/143440063/04132e29-53ec-4950-b64a-c5784b110eec)
>

>
![2](https://github.com/Tink-Bell/StenoBee/assets/143440063/485e8ca5-9fb3-435d-825b-2d08e38e0c37)
>

>

>
StenoBee, is a spelling based, orderless Steno theory for Plover.
>

>
![3](https://github.com/Tink-Bell/StenoBee/assets/143440063/68deabaf-d5f7-45b8-bed4-49bd767f10c9)
>

>
Some key points about Stenobee
>
1) Originally started, to address issues arising from local dialect differences.
>
2) Comes with a default dictionary of 13k unique words from my own posts, plus around 8k phrases taken from ngram data.
>
3) You can also make your dictionary from your own word list/raw text (using the tools at the bottom of the page)
>

>
What is StenoBee is bad at.
>
1) Captioning, and court reporting work, since the orderless non phonetic nature of it actively makes transcription related work harder.
>
2) Ambiguity with some shorter words, some memorization may be needed.
>

>
Some things that StenoBee is Good for
>
1) Can be easily customized using tools provided at the very bottom.
>
2) It's great at encoding long words and phrases into single strokes.
>

>

>
![4](https://github.com/Tink-Bell/StenoBee/assets/143440063/946df1d1-93e6-4175-ad61-739ae2486825)
>

>
![5](https://github.com/Tink-Bell/StenoBee/assets/143440063/883b4db6-3b60-4d50-af44-0c446d6291e9)
>

>
![6](https://github.com/Tink-Bell/StenoBee/assets/143440063/92ede2cc-5ae2-4501-b30e-198e6d97759d)
>

>
![7](https://github.com/Tink-Bell/StenoBee/assets/143440063/2fbca647-b029-42d5-a06b-b51de26b523b)
>

>
![8](https://github.com/Tink-Bell/StenoBee/assets/143440063/c4068cb8-bc6e-463a-b57e-7c11b1cddd20)
>

>
![9](https://github.com/Tink-Bell/StenoBee/assets/143440063/28565781-a797-4cb9-a17c-b705f7a89141)
>

>
![10](https://github.com/Tink-Bell/StenoBee/assets/143440063/33cfc9e4-b72b-467e-9a43-17d6e0786a34)
>

>
IF you are here, and you are still interested.
>
You can also make the dictionary entirely based on what you want.
>
Using these tools, you can take either raw text, or a ranked list.
>
Then make a common words dictionary from it.
>

>
Tools to filter and clean raw text, and turn it into 3 lists for easier handling.
>
https://www.dropbox.com/scl/fi/0p09wxwk1vsha8tgkgi1q/Raw-text-to-List-Tools.zip?rlkey=dem74k15jicj63ir33hn0l51g&dl=0
>

>
Tools to take your tex, and convert it into the dictionary file, replacing the "common" dictionary file.
>
https://www.dropbox.com/scl/fi/dfnrg4mn40s8mrj70d89y/List-to-Common-Json-Tools.zip?rlkey=zdx6ze8z8pg63ea26yqt9m7fg&dl=0
>

>
![11](https://github.com/Tink-Bell/StenoBee/assets/143440063/8200202a-0e7e-47e2-9850-ff3b7a72ccd9)
>



